from fireorm.Queries import Query
from interface import implements

from fireorm_repository.repositories.interface import (
    InterfaceBaseRepository,
)
from fireorm_repository.types.types import T


class BaseRepository(implements(InterfaceBaseRepository)):
    model: T

    def execute_query(
            self,
            query: Query,
    ) -> list[T]:
        """
        Execute query
        """
        items: T = query.firebase_query.get()
        return [
            self.model(id=item.id, **item._data)
            for item in items
        ]

    def get_by_field(
            self,
            field: str,
            operator: str,
            value: str | int | bool | list,
            query: Query = None
    ) -> Query:
        """
        Get by field
        """
        if query:
            query.where(field, operator, value)
        else:
            query = self.model.collection.where(field, operator, value)
        return query

    def update(self, item: T) -> T:
        return item.update()



from fireorm.Queries import Query
from interface import Interface

from fireorm_repository.types.types import T


class InterfaceBaseRepository(Interface):
    def execute_query(
            self,
            query: Query,
    ) -> list[T]:
        pass

    def get_by_field(
            self,
            field: str,
            operator: str,
            value: str | int | bool | list,
            query: Query = None
    ) -> Query:
        pass

    def update(self, item: T) -> T:
        pass



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['fireorm_repository',
 'fireorm_repository.repositories',
 'fireorm_repository.types']

package_data = \
{'': ['*']}

install_requires = \
['fireorm==0.0.14', 'python-interface==1.6.0']

setup_kwargs = {
    'name': 'fireorm-repository',
    'version': '1.0.0',
    'description': 'Layer base repository for fireorm',
    'long_description': '',
    'author': 'sergey',
    'author_email': 'alekseyserzh88@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Sergey199408081/fireorm-repository',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '==3.10.0',
}


setup(**setup_kwargs)
